[Koha-patches] [PATCH] Bug 6716: Update documentation for the letter table

Nicole C. Engard nengard at bywatersolutions.com
Thu Jul 19 03:20:27 CEST 2012


The letter table is now for slips and notices, and
had other changes necessary.
---
 installer/data/mysql/kohastructure.sql |   22 +++++++++++-----------
 1 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/installer/data/mysql/kohastructure.sql b/installer/data/mysql/kohastructure.sql
index 3b9827a..ac26b59 100644
--- a/installer/data/mysql/kohastructure.sql
+++ b/installer/data/mysql/kohastructure.sql
@@ -899,10 +899,10 @@ CREATE TABLE `import_records` (
 -- Table structure for `import_record_matches`
 --
 DROP TABLE IF EXISTS `import_record_matches`;
-CREATE TABLE `import_record_matches` (
-  `import_record_id` int(11) NOT NULL,
-  `candidate_match_id` int(11) NOT NULL,
-  `score` int(11) NOT NULL default 0,
+CREATE TABLE `import_record_matches` ( -- matches found when importing a batch of records
+  `import_record_id` int(11) NOT NULL, -- the id given to the imported bib record (import_records.import_record_id)
+  `candidate_match_id` int(11) NOT NULL, -- the biblio the imported record matches (biblio.biblionumber)
+  `score` int(11) NOT NULL default 0, -- the match score
   CONSTRAINT `import_record_matches_ibfk_1` FOREIGN KEY (`import_record_id`)
              REFERENCES `import_records` (`import_record_id`) ON DELETE CASCADE ON UPDATE CASCADE,
   KEY `record_score` (`import_record_id`, `score`)
@@ -1178,14 +1178,14 @@ CREATE TABLE `creator_templates` (
 --
 
 DROP TABLE IF EXISTS `letter`;
-CREATE TABLE `letter` ( -- table for all notice templates in Koha
-  `module` varchar(20) NOT NULL default '', -- Koha module that triggers this notice
-  `code` varchar(20) NOT NULL default '', -- unique identifier for this notice
-  `branchcode` varchar(10) default NULL, -- foreign key, linking to the branches table for the location the item was checked out
-  `name` varchar(100) NOT NULL default '', -- plain text name for this notice
-  `is_html` tinyint(1) default 0,
+CREATE TABLE `letter` ( -- table for all notice and slip templates in Koha
+  `module` varchar(20) NOT NULL default '', -- Koha module that triggers this notice or slip
+  `code` varchar(20) NOT NULL default '', -- unique identifier for this notice or slip
+  `branchcode` varchar(10) default NULL, -- the branch this notice or slip is used at (branches.branchcode)
+  `name` varchar(100) NOT NULL default '', -- plain text name for this notice or slip
+  `is_html` tinyint(1) default 0, -- does this notice or slip use HTML (1 for yes, 0 for no)
   `title` varchar(200) NOT NULL default '', -- subject line of the notice
-  `content` text, -- body text for the notice
+  `content` text, -- body text for the notice or slip
   PRIMARY KEY  (`module`,`code`, `branchcode`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
-- 
1.7.2.3



More information about the Koha-patches mailing list